gen

package
v0.1.19 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EmitContainers added in v0.0.5

func EmitContainers(in EmitInput) ([]byte, error)

Types

type Container added in v0.0.4

type Container struct {
	// Name is the struct type name.
	Name string
	// Fields are container fields (including "_" override fields which will be ignored in the final struct literal).
	Fields []resolve.ContainerField
	// Providers is the list of providers in execution order (dependencies first).
	Providers []*resolve.Provider
	// PkgPath is used to decide whether a provider call needs an import qualifier.
	PkgPath string
	// FuncName is the generated constructor function name.
	FuncName string
	// ReturnType, if non-nil, overrides the default *Name return type
	// with a custom type (e.g. an interface).
	ReturnType types.Type
}

type EmitInput

type EmitInput struct {
	// PackageName is the target package name where the container lives.
	PackageName string
	OnError     *config.OnError
	Containers  []Container
}

func (EmitInput) Append added in v0.0.4

func (ei EmitInput) Append(c Container) EmitInput

Jump to