Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EmitContainers ¶ added in v0.0.5
Types ¶
type Container ¶ added in v0.0.4
type Container struct {
// Name is the struct type name.
Name string
// Fields are container fields (including "_" override fields which will be ignored in the final struct literal).
Fields []resolve.ContainerField
// Providers is the list of providers in execution order (dependencies first).
Providers []*resolve.Provider
// PkgPath is used to decide whether a provider call needs an import qualifier.
PkgPath string
// FuncName is the generated constructor function name.
FuncName string
}
Click to show internal directories.
Click to hide internal directories.