Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EmitContainer ¶
Types ¶
type EmitInput ¶
type EmitInput struct {
// PackageName is the target package name where the container lives.
PackageName string
// ContainerName is the struct type name.
ContainerName string
// Fields are container fields (including "_" override fields which will be ignored in the final struct literal).
Fields []resolve.ContainerField
// Providers is the list of providers in execution order (dependencies first).
Providers []*resolve.Provider
// ContainerPkgPath is used to decide whether a provider call needs an import qualifier.
ContainerPkgPath string
// FuncName is the generated constructor function name.
FuncName string
}
Click to show internal directories.
Click to hide internal directories.